/****************************************************************************
 * Vertex shader program.  All vertex data (AKA geometry) passes through
 * this program.
 ****************************************************************************/

/* uniform variables supply a constant value for each vertex
 * passed through the vertex shader.
 */
uniform float uVertexScale;

/* These attritbute variables are declared as "in" variables in later
 * versions of GLSL.  This is per-vertex data: a vertex's position, color,
 * and texture coordinate.  These variables are the vertex shader's vertex
 * inputs.
 */
attribute vec2 aPosition;
attribute vec3 aColor;
attribute vec2 aTexCoord;

/* These varying variables are declared as "out" variables in later
 * versions of GLSL.  This is also per-vertex data, passed to the fragment
 * shader.
 */
varying vec3 vColor;
varying vec2 vTexCoord;

/* Note that gl_Position is a GLSL "built-in" variable, holding the current
 * vertex's position data.
 */
void main() {
  gl_Position = vec4(aPosition.x * uVertexScale,
                aPosition.y, 0, 1);
  /* Color and texture coordinate information are simply "passed through"
   * the vertex shader and sent to the fragment shader.
   */
  vColor = aColor;
  vTexCoord = aTexCoord;
}
